/* -*- Mode: C; indent-tabs-mode: t; c-basic-offset: 2; tab-width: 2 -*- */
/* gdome-xml-domimpl.h
 *
 * Copyright (C) 1999 Raph Levien <raph@acm.org>
 * Copyright (C) 2000 Mathieu Lacage <mathieu@gnu.org>
 * Copyright (C) 2000 Anders Carlsson <andersca@gnu.org>
 * Copyright (C) 2001 Paolo Casarini <paolo@casarini.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the
 * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA  02111-1307, USA.
 */

/* ----------------------------------------------------------------- */
/* ----------------------  DOMImplementation  ---------------------- */
/* ----------------------------------------------------------------- */

#ifndef GDOME_DOMIMPL_FILE
#define GDOME_DOMIMPL_FILE

struct _GdomeDOMImplementationVtab {
  void (*ref) (GdomeDOMImplementation *self, GdomeException *exc);
  void (*unref) (GdomeDOMImplementation *self, GdomeException *exc);
  void * (*query_interface) (GdomeDOMImplementation *self, const char *interface, GdomeException *exc);
  GdomeBoolean (*hasFeature) (GdomeDOMImplementation *self, GdomeDOMString *feature, GdomeDOMString *version, GdomeException *exc);
  GdomeDocumentType *(*createDocumentType) (GdomeDOMImplementation *self, GdomeDOMString *qualifiedName, GdomeDOMString *publicId, GdomeDOMString *systemId, GdomeException *exc);
  GdomeDocument *(*createDocument) (GdomeDOMImplementation *self, GdomeDOMString *namespaceURI, GdomeDOMString *qualifiedName, GdomeDocumentType *doctype, GdomeException *exc);
  GdomeDocument *(*parseFile) (GdomeDOMImplementation *self, const char *uri, GdomeException *exc);
  GdomeDocument *(*validateFile) (GdomeDOMImplementation *self, const char *uri, GdomeException *exc);
  GdomeBoolean (*saveFile) (GdomeDOMImplementation *self, const char *filename, GdomeDocument *doc, GdomeException *exc);
  void (*freeDoc) (GdomeDOMImplementation *self, GdomeDocument *doc, GdomeException *exc);
  GdomeBoolean (*saveFormatFile) (GdomeDOMImplementation *self, const char *filename, GdomeDocument *doc, int format, GdomeException *exc);
  GdomeDocument *(*createDocFromURI) (GdomeDOMImplementation *self, const char *uri, GdomeLoadingCode mode, GdomeException *exc);
  GdomeDocument *(*createDocFromMemory) (GdomeDOMImplementation *self, char *buffer, unsigned int mode, GdomeException *exc);
  GdomeDocument *(*createDocFromURIWithEntityTable) (GdomeDOMImplementation *self, const char *uri, char *entityTable[][4], GdomeLoadingCode mode, GdomeException *exc);
  GdomeDocument *(*createDocFromMemoryWithEntityTable) (GdomeDOMImplementation *self, char *buffer, char *entityTable[][4], unsigned int mode, GdomeException *exc);
  GdomeBoolean (*saveDocToFile) (GdomeDOMImplementation *self, GdomeDocument *doc, const char *filename, GdomeSavingCode mode, GdomeException *exc);
  GdomeBoolean (*saveDocToMemory) (GdomeDOMImplementation *self, GdomeDocument *doc, char **mem, GdomeSavingCode mode, GdomeException *exc);
};

typedef struct _Gdome_xml_DOMImplementation Gdome_xml_DOMImplementation;
struct _Gdome_xml_DOMImplementation {
	GdomeDOMImplementation super;
	int refcnt;
};

GdomeDOMImplementation * gdome_xml_di_mkref (void);

GdomeBoolean   gdome_xml_di_hasFeature (GdomeDOMImplementation *self,
                                        GdomeDOMString *feature,
                                        GdomeDOMString *version,
                                        GdomeException *exc);

GdomeDocumentType *gdome_xml_di_createDocumentType (GdomeDOMImplementation *self,
                                                    GdomeDOMString *qualifiedName,
                                                    GdomeDOMString *publicId,
                                                    GdomeDOMString *systemId,
                                                    GdomeException *exc);

GdomeDocument *gdome_xml_di_createDocument (GdomeDOMImplementation *self,
                                            GdomeDOMString *namespaceURI,
                                            GdomeDOMString *qualifiedName,
                                            GdomeDocumentType *doctype,
                                            GdomeException *exc);

void           gdome_xml_di_ref (GdomeDOMImplementation *self,
                                 GdomeException *exc);

void           gdome_xml_di_unref (GdomeDOMImplementation *self,
                                   GdomeException *exc);
void         * gdome_xml_di_query_interface (GdomeDOMImplementation *self,
                                             const char *interface, GdomeException *exc);

GdomeDocument * gdome_xml_di_parseFile (GdomeDOMImplementation *self,
                                        const char *uri,
                                        GdomeException *exc);
GdomeDocument * gdome_xml_di_validateFile (GdomeDOMImplementation *self,
                                           const char *uri,
                                           GdomeException *exc);
GdomeBoolean    gdome_xml_di_saveFile  (GdomeDOMImplementation *self,
                                        const char *filename,
                                        GdomeDocument *doc,
                                        GdomeException *exc);
void            gdome_xml_di_freeDoc   (GdomeDOMImplementation *self,
                                        GdomeDocument *doc,
                                        GdomeException *exc);
GdomeBoolean    gdome_xml_di_saveFile  (GdomeDOMImplementation *self,
                                        const char *filename,
                                        GdomeDocument *doc,
                                        GdomeException *exc);
GdomeBoolean    gdome_xml_di_saveFormatFile  (GdomeDOMImplementation *self,
                                              const char *filename,
                                              GdomeDocument *doc,
                                              int format,
                                              GdomeException *exc);
GdomeDocument * gdome_xml_di_createDocFromURI (GdomeDOMImplementation *self,
                                               const char *uri,
                                               GdomeLoadingCode mode,
                                               GdomeException *exc);
GdomeDocument * gdome_xml_di_createDocFromMemory (GdomeDOMImplementation *self,
                                                  char *buffer,
                                                  GdomeLoadingCode mode,
                                                  GdomeException *exc);
GdomeDocument * gdome_xml_di_createDocFromURIWithEntityTable (GdomeDOMImplementation *self,
                                                              const char *uri,
                                                              char *entityTable[][4],
                                                              GdomeLoadingCode mode,
                                                              GdomeException *exc);
GdomeDocument * gdome_xml_di_createDocFromMemoryWithEntityTable (GdomeDOMImplementation *self,
                                                                 char *buffer,
                                                                 char *entityTable[][4],
                                                                 GdomeLoadingCode mode,
                                                                 GdomeException *exc);
GdomeBoolean gdome_xml_di_saveDocToFile (GdomeDOMImplementation *self,
                                         GdomeDocument *doc,
                                         const char *filename,
                                         GdomeSavingCode mode,
                                         GdomeException *exc);
GdomeBoolean gdome_xml_di_saveDocToMemory (GdomeDOMImplementation *self,
                                           GdomeDocument *doc,
                                           char **mem,
                                           GdomeSavingCode mode,
                                           GdomeException *exc);

const GdomeDOMImplementationVtab gdome_xml_di_vtab;



#endif /* GDOME_DOMIMPL_FILE */


